@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.9";
+        "11.0.22";
 
     private static final String java_version_date =
-        "2020-10-20";
+        "2024-01-16";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.9+11";
+        "11.0.22+7";
 
     private static final String VERSION_NUMBER =
-        "11.0.9";
+        "11.0.22";
 
     private static final String VERSION_BUILD =
-        "11";
+        "7";
 
     private static final String VERSION_PRE =
         "";
@@ -65,24 +65,24 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String VENDOR =
-        "AdoptOpenJDK";
+        "Eclipse Adoptium";
 
     private static final String VENDOR_URL =
-        "https://adoptopenjdk.net/";
+        "https://adoptium.net/";
 
     // The remaining VENDOR_* fields must not be final,
     // so that they can be redefined by jlink plugins
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "AdoptOpenJDK";
+        "Temurin-11.0.22+7";
 
     private static String VENDOR_URL_BUG =
-        "https://github.com/AdoptOpenJDK/openjdk-support/issues";
+        "https://github.com/adoptium/adoptium-support/issues";
 
     // This field is read by HotSpot
     private static String VENDOR_URL_VM_BUG =
-        "https://github.com/AdoptOpenJDK/openjdk-support/issues";
+        "https://github.com/adoptium/adoptium-support/issues";
 
     static {
         init();
